@@ -609,18 +609,15 @@ BasicLibInfo* BasicLibInfo::Create( SotStorageStream& rSStream )
         pInfo->bDoLoad = bDoLoad;
 
         // Den Namen der Lib...
-        String aName;
-        rSStream.ReadByteString(aName);
+        String aName = rSStream.ReadUniOrByteString(rSStream.GetStreamCharSet());
         pInfo->SetLibName( aName );
 
         // Absoluter Pfad....
-        String aStorageName;
-        rSStream.ReadByteString(aStorageName);
+        String aStorageName = rSStream.ReadUniOrByteString(rSStream.GetStreamCharSet());
         pInfo->SetStorageName( aStorageName );
 
         // Relativer Pfad...
-        String aRelStorageName;
-        rSStream.ReadByteString(aRelStorageName);
+        String aRelStorageName = rSStream.ReadUniOrByteString(rSStream.GetStreamCharSet());
         pInfo->SetRelStorageName( aRelStorageName );
 
         if ( nVer >= 2 )
@@ -980,7 +977,7 @@ void BasicManager::LoadBasicManager( SotStorage& rStorage, const String& rBaseUR
             if ( pLibs->aBasicLibPath.Len() )
             {
                 // Lib im Pfad suchen...
-                String aSearchFile = pInfo->GetRelStorageName();
+                rtl::OUString aSearchFile = pInfo->GetRelStorageName();
                 SvtPathOptions aPathCFG;
                 if( aPathCFG.SearchFile( aSearchFile, SvtPathOptions::PATH_BASIC ) )
                 {
@@ -1039,8 +1036,7 @@ void BasicManager::LoadOldBasicManager( SotStorage& rStorage )
         // und es geht weiter...
     }
     xManagerStream->Seek( nBasicEndOff+1 ); // +1: 0x00 als Trenner
-    String aLibs;
-    xManagerStream->ReadByteString(aLibs);
+    String aLibs = xManagerStream->ReadUniOrByteString(xManagerStream->GetStreamCharSet());
     xManagerStream->SetBufferSize( 0 );
     xManagerStream.Clear(); // Sream schliessen
 
@@ -1222,8 +1218,7 @@ BOOL BasicManager::ImpLoadLibary( BasicLibInfo* pLibInfo, SotStorage* pCurStorag
                 *xBasicStream >> nPasswordMarker;
                 if ( ( nPasswordMarker == PASSWORD_MARKER ) && !xBasicStream->IsEof() )
                 {
-                    String aPassword;
-                    xBasicStream->ReadByteString(aPassword);
+                    String aPassword = xBasicStream->ReadUniOrByteString(xBasicStream->GetStreamCharSet());
                     pLibInfo->SetPassword( aPassword );
                 }
                 xBasicStream->SetCryptMaskKey(rtl::OString());
