@@ -584,8 +584,10 @@ BOOL SbxObject::LoadData( SvStream& rStrm, USHORT nVer )
         aData.pObj = this;
     sal_uInt32 nSize;
     XubString aDfltProp;
-    rStrm.ReadByteString( aClassName, RTL_TEXTENCODING_ASCII_US );
-    rStrm.ReadByteString( aDfltProp, RTL_TEXTENCODING_ASCII_US );
+    aClassName = read_lenPrefixed_uInt8s_ToOUString<sal_uInt16>(rStrm,
+        RTL_TEXTENCODING_ASCII_US);
+    aDfltProp = read_lenPrefixed_uInt8s_ToOUString<sal_uInt16>(rStrm,
+        RTL_TEXTENCODING_ASCII_US);
     ULONG nPos = rStrm.Tell();
     rStrm >> nSize;
     if( !LoadPrivateData( rStrm, nVer ) )
@@ -763,7 +765,8 @@ void SbxObject::Dump( SvStream& rStrm, BOOL bFill )
                 aLine += aAttrs2;
             if( !pVar->IsA( TYPE(SbxMethod) ) )
                 aLine.AppendAscii( "  !! Not a Method !!" );
-            rStrm.WriteByteString( aLine, RTL_TEXTENCODING_ASCII_US );
+            write_lenPrefixed_uInt8s_FromOUString<sal_uInt16>(rStrm, aLine,
+                RTL_TEXTENCODING_ASCII_US);
 
             // bei Object-Methods auch das Object ausgeben
             if ( pVar->GetValues_Impl().eType == SbxOBJECT &&
@@ -796,7 +799,8 @@ void SbxObject::Dump( SvStream& rStrm, BOOL bFill )
                     aLine += aAttrs3;
                 if( !pVar->IsA( TYPE(SbxProperty) ) )
                     aLine.AppendAscii( "  !! Not a Property !!" );
-                rStrm.WriteByteString( aLine, RTL_TEXTENCODING_ASCII_US );
+                write_lenPrefixed_uInt8s_FromOUString<sal_uInt16>(rStrm, aLine,
+                    RTL_TEXTENCODING_ASCII_US);
 
                 // bei Object-Properties auch das Object ausgeben
                 if ( pVar->GetValues_Impl().eType == SbxOBJECT &&
@@ -835,11 +839,6 @@ void SbxObject::Dump( SvStream& rStrm, BOOL bFill )
     --nLevel;
 }
 
-SvDispatch* SbxObject::GetSvDispatch()
-{
-    return NULL;
-}
-
 SbxClassType SbxMethod::GetClass() const
 {
     return SbxCLASS_METHOD;
