@@ -221,7 +221,7 @@ static char const aChckXML[]    = { '<', '?', 'x', 'm', 'l' };      // = 6.0
 /*N*/   {
 /*N*/       Insert( new XColorEntry(
                         Color( aColTab[n] ),
-                        String( ResId( aResId[ n ], rRes ) )
+                        String( ResId( aResId[ n ], rRes ).toString() )
                     ),
                     n
             );
@@ -545,7 +545,7 @@ static char const aChckXML[]    = { '<', '?', 'x', 'm', 'l' };      // = 6.0
 /*N*/           rIn >> nIndex;
 /*N*/
 /*N*/           // UNICODE: rIn >> aLclName;
-/*N*/           rIn.ReadByteString(aLclName);
+/*N*/           aLclName = rIn.ReadUniOrByteString(rIn.GetStreamCharSet());
 /*N*/           aLclName = ConvertName( aLclName );
 /*N*/
 /*N*/           rIn >> nRed;
@@ -570,7 +570,7 @@ static char const aChckXML[]    = { '<', '?', 'x', 'm', 'l' };      // = 6.0
 /*N*/           rIn >> nIndex;
 /*N*/
 /*N*/           // UNICODE: rIn >> aLclName;
-/*N*/           rIn.ReadByteString(aLclName);
+/*N*/           aLclName = rIn.ReadUniOrByteString(rIn.GetStreamCharSet());
 /*N*/           aLclName = ConvertName( aLclName );
 /*N*/
 /*N*/           /*if( aIOC.GetVersion() >= 0 )*/
